@@ -19,7 +19,7 @@ type ColumnMappings = (u32, BTreeMap<LineSegment, ColumnRowMappings>);
 
 impl BottomLayout {
     pub fn get_movement_mappings(&mut self) {
-        #[allow(clippy::suspicious_operation_groupings)] // Have to enable this, clippy really doesn't like me doing this with tuples...
+        #[expect(clippy::suspicious_operation_groupings)] // Have to enable this, clippy really doesn't like me doing this with tuples...
         fn is_intersecting(a: LineSegment, b: LineSegment) -> bool {
             a.0 >= b.0 && a.1 <= b.1
                 || a.1 >= b.1 && a.0 <= b.0
@@ -663,21 +663,20 @@ impl BottomLayout {
         BottomLayout {
             total_row_height_ratio: 3,
             rows: vec![
-                BottomRow::new(vec![BottomCol::new(vec![
-                    BottomColRow::new(vec![cpu]).canvas_handled()
+                BottomRow::new(vec![
+                    BottomCol::new(vec![BottomColRow::new(vec![cpu]).canvas_handled()])
+                        .canvas_handled(),
                 ])
-                .canvas_handled()])
                 .canvas_handled(),
-                BottomRow::new(vec![BottomCol::new(vec![BottomColRow::new(vec![
-                    mem, net,
+                BottomRow::new(vec![
+                    BottomCol::new(vec![BottomColRow::new(vec![mem, net]).canvas_handled()])
+                        .canvas_handled(),
                 ])
-                .canvas_handled()])
-                .canvas_handled()])
                 .canvas_handled(),
-                BottomRow::new(vec![BottomCol::new(vec![
-                    BottomColRow::new(vec![table]).canvas_handled()
+                BottomRow::new(vec![
+                    BottomCol::new(vec![BottomColRow::new(vec![table]).canvas_handled()])
+                        .canvas_handled(),
                 ])
-                .canvas_handled()])
                 .canvas_handled(),
                 BottomRow::new(table_widgets).canvas_handled(),
             ],
@@ -745,11 +744,6 @@ impl BottomRow {
         self.constraint = IntermediaryConstraint::CanvasHandled { ratio: None };
         self
     }
-
-    pub fn grow(mut self, minimum: Option<u32>) -> Self {
-        self.constraint = IntermediaryConstraint::Grow { minimum };
-        self
-    }
 }
 
 /// Represents a single column in the layout.  We assume that even if the column
@@ -785,11 +779,6 @@ impl BottomCol {
         self.constraint = IntermediaryConstraint::CanvasHandled { ratio: None };
         self
     }
-
-    pub fn grow(mut self, minimum: Option<u32>) -> Self {
-        self.constraint = IntermediaryConstraint::Grow { minimum };
-        self
-    }
 }
 
 #[derive(Clone, Default, Debug)]
