@@ -1,29 +1,34 @@
+//! Code related to drawing.
+//!
+//! Note that eventually this should not contain any widget-specific draw code, but rather just generic code
+//! or components.
+
 pub mod components;
-mod dialogs;
+pub mod dialogs;
 mod drawing_utils;
 mod widgets;
 
 use itertools::izip;
 use tui::{
+    Frame, Terminal,
     backend::Backend,
     layout::{Constraint, Direction, Layout, Rect},
     text::Span,
     widgets::Paragraph,
-    Frame, Terminal,
 };
 
 use crate::{
     app::{
-        layout_manager::{BottomColRow, BottomLayout, BottomWidgetType, IntermediaryConstraint},
         App,
+        layout_manager::{BottomColRow, BottomLayout, BottomWidgetType, IntermediaryConstraint},
     },
     constants::*,
-    options::config::style::ColourPalette,
+    options::config::style::Styles,
 };
 
 /// Handles the canvas' state.
 pub struct Painter {
-    pub colours: ColourPalette,
+    pub styles: Styles,
     previous_height: u16,
     previous_width: u16,
 
@@ -47,7 +52,7 @@ pub enum LayoutConstraint {
 }
 
 impl Painter {
-    pub fn init(layout: BottomLayout, styling: ColourPalette) -> anyhow::Result<Self> {
+    pub fn init(layout: BottomLayout, styling: Styles) -> anyhow::Result<Self> {
         // Now for modularity; we have to also initialize the base layouts!
         // We want to do this ONCE and reuse; after this we can just construct
         // based on the console size.
@@ -131,7 +136,7 @@ impl Painter {
         });
 
         let painter = Painter {
-            colours: styling,
+            styles: styling,
             previous_height: 0,
             previous_width: 0,
             row_constraints,
@@ -149,9 +154,9 @@ impl Painter {
     pub fn get_border_style(&self, widget_id: u64, selected_widget_id: u64) -> tui::style::Style {
         let is_on_widget = widget_id == selected_widget_id;
         if is_on_widget {
-            self.colours.highlighted_border_style
+            self.styles.highlighted_border_style
         } else {
-            self.colours.border_style
+            self.styles.border_style
         }
     }
 
@@ -159,7 +164,7 @@ impl Painter {
         f.render_widget(
             Paragraph::new(Span::styled(
                 "Frozen, press 'f' to unfreeze",
-                self.colours.selected_text_style,
+                self.styles.selected_text_style,
             )),
             Layout::default()
                 .horizontal_margin(1)
@@ -174,14 +179,14 @@ impl Painter {
         use BottomWidgetType::*;
 
         terminal.draw(|f| {
-            let (terminal_size, frozen_draw_loc) = if app_state.frozen_state.is_frozen() {
+            let (terminal_size, frozen_draw_loc) = if app_state.data_store.is_frozen() {
                 // TODO: Remove built-in cache?
                 let split_loc = Layout::default()
                     .constraints([Constraint::Min(0), Constraint::Length(1)])
-                    .split(f.size());
+                    .split(f.area());
                 (split_loc[0], Some(split_loc[1]))
             } else {
-                (f.size(), None)
+                (f.area(), None)
             };
             let terminal_height = terminal_size.height;
             let terminal_width = terminal_size.width;
@@ -195,6 +200,7 @@ impl Painter {
                 self.previous_width = terminal_width;
             }
 
+            // TODO: We should probably remove this or make it done elsewhere, not the responsibility of the app.
             if app_state.should_get_widget_bounds() {
                 // If we're force drawing, reset ALL mouse boundaries.
                 for widget in app_state.widget_map.values_mut() {
@@ -202,15 +208,16 @@ impl Painter {
                     widget.bottom_right_corner = None;
                 }
 
-                // Reset dd_dialog...
-                app_state.delete_dialog_state.button_positions = vec![];
+                // Reset process kill dialog button locations...
+                app_state.process_kill_dialog.handle_redraw();
 
-                // Reset battery dialog...
+                // Reset battery dialog button locations...
                 for battery_widget in app_state.states.battery_state.widget_states.values_mut() {
                     battery_widget.tab_click_locs = None;
                 }
             }
 
+            // TODO: Make drawing dialog generic.
             if app_state.help_dialog_state.is_showing_help {
                 let gen_help_len = GENERAL_HELP_TEXT.len() as u16 + 3;
                 let border_len = terminal_height.saturating_sub(gen_help_len) / 2;
@@ -243,46 +250,32 @@ impl Painter {
                     .split(vertical_dialog_chunk[1]);
 
                 self.draw_help_dialog(f, app_state, middle_dialog_chunk[1]);
-            } else if app_state.delete_dialog_state.is_showing_dd {
-                let dd_text = self.get_dd_spans(app_state);
+            } else if app_state.process_kill_dialog.is_open() {
+                // FIXME: For width, just limit to a max size or full width. For height, not sure. Maybe pass max and let child handle?
+                let horizontal_padding = if terminal_width < 100 { 0 } else { 5 };
+                let vertical_padding = if terminal_height < 100 { 0 } else { 5 };
 
-                let text_width = if terminal_width < 100 {
-                    terminal_width * 90 / 100
-                } else {
-                    terminal_width * 50 / 100
-                };
-
-                let text_height = if cfg!(target_os = "windows")
-                    || !app_state.app_config_fields.is_advanced_kill
-                {
-                    7
-                } else {
-                    22
-                };
-
-                let vertical_bordering = terminal_height.saturating_sub(text_height) / 2;
                 let vertical_dialog_chunk = Layout::default()
                     .direction(Direction::Vertical)
                     .constraints([
-                        Constraint::Length(vertical_bordering),
-                        Constraint::Length(text_height),
-                        Constraint::Length(vertical_bordering),
+                        Constraint::Length(vertical_padding),
+                        Constraint::Fill(1),
+                        Constraint::Length(vertical_padding),
                     ])
-                    .split(terminal_size);
+                    .areas::<3>(terminal_size)[1];
 
-                let horizontal_bordering = terminal_width.saturating_sub(text_width) / 2;
-                let middle_dialog_chunk = Layout::default()
+                let dialog_draw_area = Layout::default()
                     .direction(Direction::Horizontal)
                     .constraints([
-                        Constraint::Length(horizontal_bordering),
-                        Constraint::Length(text_width),
-                        Constraint::Length(horizontal_bordering),
+                        Constraint::Length(horizontal_padding),
+                        Constraint::Fill(1),
+                        Constraint::Length(horizontal_padding),
                     ])
-                    .split(vertical_dialog_chunk[1]);
+                    .areas::<3>(vertical_dialog_chunk)[1];
 
-                // This is a bit nasty, but it works well... I guess.
-                app_state.delete_dialog_state.is_showing_dd =
-                    self.draw_dd_dialog(f, dd_text, app_state, middle_dialog_chunk[1]);
+                app_state
+                    .process_kill_dialog
+                    .draw(f, dialog_draw_area, &self.styles);
             } else if app_state.is_expanded {
                 if let Some(frozen_draw_loc) = frozen_draw_loc {
                     self.draw_frozen_indicator(f, frozen_draw_loc);
@@ -333,64 +326,61 @@ impl Painter {
                                 _ => 0,
                             };
 
-                        self.draw_process(f, app_state, rect[0], true, widget_id);
+                        self.draw_process(f, app_state, rect[0], widget_id);
+                    }
+                    Battery =>
+                    {
+                        #[cfg(feature = "battery")]
+                        self.draw_battery(f, app_state, rect[0], app_state.current_widget.widget_id)
                     }
-                    Battery => self.draw_battery(
-                        f,
-                        app_state,
-                        rect[0],
-                        true,
-                        app_state.current_widget.widget_id,
-                    ),
                     _ => {}
                 }
             } else if app_state.app_config_fields.use_basic_mode {
-                // Basic mode.  This basically removes all graphs but otherwise
+                // Basic mode. This basically removes all graphs but otherwise
                 // the same info.
                 if let Some(frozen_draw_loc) = frozen_draw_loc {
                     self.draw_frozen_indicator(f, frozen_draw_loc);
                 }
 
-                let actual_cpu_data_len = app_state.converted_data.cpu_data.len().saturating_sub(1);
+                let data = app_state.data_store.get_data();
+                let actual_cpu_data_len = data.cpu_harvest.len();
 
                 // This fixes #397, apparently if the height is 1, it can't render the CPU
                 // bars...
                 let cpu_height = {
-                    let c =
-                        (actual_cpu_data_len / 4) as u16 + u16::from(actual_cpu_data_len % 4 != 0);
+                    let c = (actual_cpu_data_len / 4) as u16
+                        + u16::from(actual_cpu_data_len % 4 != 0)
+                        + u16::from(
+                            app_state.app_config_fields.dedicated_average_row
+                                && actual_cpu_data_len.saturating_sub(1) % 4 != 0,
+                        );
 
-                    if c <= 1 {
-                        1
-                    } else {
-                        c
-                    }
+                    if c <= 1 { 1 } else { c }
                 };
 
                 let mut mem_rows = 1;
 
-                if app_state.converted_data.swap_labels.is_some() {
+                if data.swap_harvest.is_some() {
                     mem_rows += 1; // add row for swap
                 }
 
                 #[cfg(feature = "zfs")]
                 {
-                    if app_state.converted_data.arc_labels.is_some() {
+                    if data.arc_harvest.is_some() {
                         mem_rows += 1; // add row for arc
                     }
                 }
 
                 #[cfg(not(target_os = "windows"))]
                 {
-                    if app_state.converted_data.cache_labels.is_some() {
+                    if data.cache_harvest.is_some() {
                         mem_rows += 1;
                     }
                 }
 
                 #[cfg(feature = "gpu")]
                 {
-                    if let Some(gpu_data) = &app_state.converted_data.gpu_data {
-                        mem_rows += gpu_data.len() as u16; // add row(s) for gpu
-                    }
+                    mem_rows += data.gpu_harvest.len() as u16; // add row(s) for gpu
                 }
 
                 if mem_rows == 1 {
@@ -440,18 +430,16 @@ impl Painter {
                                         ProcSort => 2,
                                         _ => 0,
                                     };
-                                self.draw_process(f, app_state, vertical_chunks[3], false, wid);
+                                self.draw_process(f, app_state, vertical_chunks[3], wid);
                             }
                             Temp => {
                                 self.draw_temp_table(f, app_state, vertical_chunks[3], widget_id)
                             }
-                            Battery => self.draw_battery(
-                                f,
-                                app_state,
-                                vertical_chunks[3],
-                                false,
-                                widget_id,
-                            ),
+                            Battery =>
+                            {
+                                #[cfg(feature = "battery")]
+                                self.draw_battery(f, app_state, vertical_chunks[3], widget_id)
+                            }
                             _ => {}
                         }
                     }
@@ -725,8 +713,12 @@ impl Painter {
                     Net => self.draw_network(f, app_state, *draw_loc, widget.widget_id),
                     Temp => self.draw_temp_table(f, app_state, *draw_loc, widget.widget_id),
                     Disk => self.draw_disk_table(f, app_state, *draw_loc, widget.widget_id),
-                    Proc => self.draw_process(f, app_state, *draw_loc, true, widget.widget_id),
-                    Battery => self.draw_battery(f, app_state, *draw_loc, true, widget.widget_id),
+                    Proc => self.draw_process(f, app_state, *draw_loc, widget.widget_id),
+                    Battery =>
+                    {
+                        #[cfg(feature = "battery")]
+                        self.draw_battery(f, app_state, *draw_loc, widget.widget_id)
+                    }
                     _ => {}
                 }
             }
