@@ -53,6 +53,8 @@ use tui::{Terminal, backend::CrosstermBackend};
 use utils::logging::*;
 use utils::{cancellation_token::CancellationToken, conversion::*};
 
+use crate::collection::Data;
+
 // Used for heap allocation debugging purposes.
 // #[global_allocator]
 // static ALLOC: dhat::Alloc = dhat::Alloc;
@@ -219,17 +221,21 @@ fn create_collection_thread(
     let use_current_cpu_total = app_config_fields.use_current_cpu_total;
     let unnormalized_cpu = app_config_fields.unnormalized_cpu;
     let show_average_cpu = app_config_fields.show_average_cpu;
-    let update_time = app_config_fields.update_rate;
+    let update_sleep = app_config_fields.update_rate;
 
     thread::spawn(move || {
-        let mut data_state = collection::DataCollector::new(filters);
+        let mut data_collector = collection::DataCollector::new(filters);
 
-        data_state.set_collection(used_widget_set);
-        data_state.set_use_current_cpu_total(use_current_cpu_total);
-        data_state.set_unnormalized_cpu(unnormalized_cpu);
-        data_state.set_show_average_cpu(show_average_cpu);
+        data_collector.set_collection(used_widget_set);
+        data_collector.set_use_current_cpu_total(use_current_cpu_total);
+        data_collector.set_unnormalized_cpu(unnormalized_cpu);
+        data_collector.set_show_average_cpu(show_average_cpu);
 
-        data_state.init();
+        data_collector.update_data();
+        data_collector.data = Data::default();
+
+        // Tiny sleep I guess? To go between the first update above and the first update in the loop.
+        std::thread::sleep(Duration::from_millis(5));
 
         loop {
             // Check once at the very top... don't block though.
@@ -243,12 +249,12 @@ fn create_collection_thread(
                 // trace!("Received message in collection thread: {message:?}");
                 match message {
                     CollectionThreadEvent::Reset => {
-                        data_state.data.cleanup();
+                        data_collector.data.cleanup();
                     }
                 }
             }
 
-            data_state.update_data();
+            data_collector.update_data();
 
             // Yet another check to bail if needed... do not block!
             if let Some(is_terminated) = cancellation_token.try_check() {
@@ -257,14 +263,15 @@ fn create_collection_thread(
                 }
             }
 
-            let event = BottomEvent::Update(Box::from(data_state.data));
-            data_state.data = collection::Data::default();
+            let event = BottomEvent::Update(Box::from(data_collector.data));
+            data_collector.data = Data::default();
+
             if sender.send(event).is_err() {
                 break;
             }
 
             // Sleep while allowing for interruptions...
-            if cancellation_token.sleep_with_cancellation(Duration::from_millis(update_time)) {
+            if cancellation_token.sleep_with_cancellation(Duration::from_millis(update_sleep)) {
                 break;
             }
         }
