@@ -1,5 +1,6 @@
-pub mod proc_widget_column;
-pub mod proc_widget_data;
+pub mod process_columns;
+pub mod process_data;
+pub mod query;
 mod sort_table;
 
 use std::{borrow::Cow, collections::BTreeMap};
@@ -7,22 +8,22 @@ use std::{borrow::Cow, collections::BTreeMap};
 use hashbrown::{HashMap, HashSet};
 use indexmap::IndexSet;
 use itertools::Itertools;
-pub use proc_widget_column::*;
-pub use proc_widget_data::*;
+pub use process_columns::*;
+pub use process_data::*;
+use query::{ProcessQuery, parse_query};
 use sort_table::SortTableColumn;
 
 use crate::{
     app::{
-        data_farmer::{DataCollection, ProcessData},
-        query::*,
         AppConfigFields, AppSearchState,
+        data::{ProcessData, StoredData},
     },
     canvas::components::data_table::{
         Column, ColumnHeader, ColumnWidthBounds, DataTable, DataTableColumn, DataTableProps,
         DataTableStyling, SortColumn, SortDataTable, SortDataTableProps, SortOrder, SortsRow,
     },
-    data_collection::processes::{Pid, ProcessHarvest},
-    options::config::style::ColourPalette,
+    collection::processes::{Pid, ProcessHarvest},
+    options::config::style::Styles,
 };
 
 /// ProcessSearchState only deals with process' search's current settings and
@@ -59,9 +60,83 @@ impl ProcessSearchState {
     }
 }
 
+/// Whether to expand or collapse by default.
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub enum ProcWidgetMode {
-    Tree { collapsed_pids: HashSet<Pid> },
+pub(crate) enum TreeCollapsed {
+    DefaultCollapse { expanded_pids: HashSet<Pid> },
+    DefaultExpand { collapsed_pids: HashSet<Pid> },
+}
+
+impl TreeCollapsed {
+    /// Creates a new [`TreeCollapsed`].
+    pub(crate) fn new(default_collapsed: bool) -> Self {
+        if default_collapsed {
+            TreeCollapsed::DefaultCollapse {
+                expanded_pids: HashSet::new(),
+            }
+        } else {
+            TreeCollapsed::DefaultExpand {
+                collapsed_pids: HashSet::new(),
+            }
+        }
+    }
+
+    /// Check whether the given PID is collapsed.
+    pub(crate) fn is_collapsed(&self, pid: Pid) -> bool {
+        match self {
+            TreeCollapsed::DefaultCollapse { expanded_pids } => !expanded_pids.contains(&pid),
+            TreeCollapsed::DefaultExpand { collapsed_pids } => collapsed_pids.contains(&pid),
+        }
+    }
+
+    /// Collapse the given PID.
+    pub(crate) fn collapse(&mut self, pid: Pid) {
+        match self {
+            TreeCollapsed::DefaultCollapse { expanded_pids } => {
+                expanded_pids.remove(&pid);
+            }
+            TreeCollapsed::DefaultExpand { collapsed_pids } => {
+                collapsed_pids.insert(pid);
+            }
+        }
+    }
+
+    /// Expand the given PID.
+    pub(crate) fn expand(&mut self, pid: Pid) {
+        match self {
+            TreeCollapsed::DefaultCollapse { expanded_pids } => {
+                expanded_pids.insert(pid);
+            }
+            TreeCollapsed::DefaultExpand { collapsed_pids } => {
+                collapsed_pids.remove(&pid);
+            }
+        }
+    }
+
+    /// Toggle the given PID.
+    pub(crate) fn toggle(&mut self, pid: Pid) {
+        match self {
+            TreeCollapsed::DefaultCollapse { expanded_pids } => {
+                if expanded_pids.contains(&pid) {
+                    expanded_pids.remove(&pid);
+                } else {
+                    expanded_pids.insert(pid);
+                }
+            }
+            TreeCollapsed::DefaultExpand { collapsed_pids } => {
+                if collapsed_pids.contains(&pid) {
+                    collapsed_pids.remove(&pid);
+                } else {
+                    collapsed_pids.insert(pid);
+                }
+            }
+        }
+    }
+}
+
+#[derive(Clone, Debug, Eq, PartialEq)]
+pub(crate) enum ProcWidgetMode {
+    Tree(TreeCollapsed),
     Grouped,
     Normal,
 }
@@ -75,8 +150,9 @@ fn make_column(column: ProcColumn) -> SortColumn<ProcColumn> {
 
     match column {
         CpuPercent => SortColumn::new(CpuPercent).default_descending(),
-        MemoryVal => SortColumn::new(MemoryVal).default_descending(),
-        MemoryPercent => SortColumn::new(MemoryPercent).default_descending(),
+        MemValue => SortColumn::new(MemValue).default_descending(),
+        MemPercent => SortColumn::new(MemPercent).default_descending(),
+        VirtualMem => SortColumn::new(VirtualMem).default_descending(),
         Pid => SortColumn::new(Pid),
         Count => SortColumn::new(Count),
         Name => SortColumn::soft(Name, Some(0.3)),
@@ -89,7 +165,7 @@ fn make_column(column: ProcColumn) -> SortColumn<ProcColumn> {
         State => SortColumn::hard(State, 9),
         Time => SortColumn::new(Time),
         #[cfg(feature = "gpu")]
-        GpuMem => SortColumn::new(GpuMem).default_descending(),
+        GpuMemValue => SortColumn::new(GpuMemValue).default_descending(),
         #[cfg(feature = "gpu")]
         GpuMemPercent => SortColumn::new(GpuMemPercent).default_descending(),
         #[cfg(feature = "gpu")]
@@ -113,6 +189,7 @@ pub enum ProcWidgetColumn {
     ProcNameOrCommand,
     Cpu,
     Mem,
+    VirtualMem,
     ReadPerSecond,
     WritePerSecond,
     TotalRead,
@@ -129,7 +206,7 @@ pub enum ProcWidgetColumn {
 // This is temporary. Switch back to `ProcColumn` later!
 
 pub struct ProcWidgetState {
-    pub mode: ProcWidgetMode,
+    pub(crate) mode: ProcWidgetMode,
 
     /// The state of the search box.
     pub proc_search: ProcessSearchState,
@@ -159,7 +236,7 @@ pub struct ProcWidgetState {
 }
 
 impl ProcWidgetState {
-    fn new_sort_table(config: &AppConfigFields, palette: &ColourPalette) -> SortTable {
+    fn new_sort_table(config: &AppConfigFields, palette: &Styles) -> SortTable {
         const COLUMNS: [Column<SortTableColumn>; 1] = [Column::hard(SortTableColumn, 7)];
 
         let props = DataTableProps {
@@ -176,7 +253,7 @@ impl ProcWidgetState {
     }
 
     fn new_process_table(
-        config: &AppConfigFields, colours: &ColourPalette, columns: Vec<SortColumn<ProcColumn>>,
+        config: &AppConfigFields, colours: &Styles, columns: Vec<SortColumn<ProcColumn>>,
         default_index: usize, default_order: SortOrder,
     ) -> ProcessTable {
         let inner_props = DataTableProps {
@@ -197,9 +274,9 @@ impl ProcWidgetState {
         DataTable::new_sortable(columns, props, styling)
     }
 
-    pub fn new(
+    pub(crate) fn new(
         config: &AppConfigFields, mode: ProcWidgetMode, table_config: ProcTableConfig,
-        colours: &ColourPalette, config_columns: &Option<IndexSet<ProcWidgetColumn>>,
+        colours: &Styles, config_columns: &Option<IndexSet<ProcWidgetColumn>>,
     ) -> Self {
         let process_search_state = {
             let mut pss = ProcessSearchState::default();
@@ -247,11 +324,12 @@ impl ProcWidgetState {
                             ProcWidgetColumn::Cpu => CpuPercent,
                             ProcWidgetColumn::Mem => {
                                 if mem_as_values {
-                                    MemoryVal
+                                    MemValue
                                 } else {
-                                    MemoryPercent
+                                    MemPercent
                                 }
                             }
+                            ProcWidgetColumn::VirtualMem => VirtualMem,
                             ProcWidgetColumn::ReadPerSecond => ReadPerSecond,
                             ProcWidgetColumn::WritePerSecond => WritePerSecond,
                             ProcWidgetColumn::TotalRead => TotalRead,
@@ -262,7 +340,7 @@ impl ProcWidgetState {
                             #[cfg(feature = "gpu")]
                             ProcWidgetColumn::GpuMem => {
                                 if mem_as_values {
-                                    GpuMem
+                                    GpuMemValue
                                 } else {
                                     GpuMemPercent
                                 }
@@ -279,11 +357,7 @@ impl ProcWidgetState {
                         if is_count { Count } else { Pid },
                         if is_command { Command } else { Name },
                         CpuPercent,
-                        if mem_as_values {
-                            MemoryVal
-                        } else {
-                            MemoryPercent
-                        },
+                        if mem_as_values { MemValue } else { MemPercent },
                         ReadPerSecond,
                         WritePerSecond,
                         TotalRead,
@@ -305,7 +379,8 @@ impl ProcWidgetState {
 
                 match col.inner() {
                     CpuPercent => ProcWidgetColumn::Cpu,
-                    MemoryVal | MemoryPercent => ProcWidgetColumn::Mem,
+                    MemValue | MemPercent => ProcWidgetColumn::Mem,
+                    VirtualMem => ProcWidgetColumn::VirtualMem,
                     Pid | Count => ProcWidgetColumn::PidOrCount,
                     Name | Command => ProcWidgetColumn::ProcNameOrCommand,
                     ReadPerSecond => ProcWidgetColumn::ReadPerSecond,
@@ -316,7 +391,7 @@ impl ProcWidgetState {
                     User => ProcWidgetColumn::User,
                     Time => ProcWidgetColumn::Time,
                     #[cfg(feature = "gpu")]
-                    GpuMem | GpuMemPercent => ProcWidgetColumn::GpuMem,
+                    GpuMemValue | GpuMemPercent => ProcWidgetColumn::GpuMem,
                     #[cfg(feature = "gpu")]
                     GpuUtilPercent => ProcWidgetColumn::GpuUtil,
                 }
@@ -381,11 +456,11 @@ impl ProcWidgetState {
         self.column_mapping
             .get_index_of(&ProcWidgetColumn::Mem)
             .and_then(|index| self.table.columns.get(index))
-            .map(|col| matches!(col.inner(), ProcColumn::MemoryPercent))
+            .map(|col| matches!(col.inner(), ProcColumn::MemPercent))
             .unwrap_or(false)
     }
 
-    fn get_query(&self) -> &Option<Query> {
+    fn get_query(&self) -> &Option<ProcessQuery> {
         if self.proc_search.search_state.is_invalid_or_blank_search() {
             &None
         } else {
@@ -398,20 +473,19 @@ impl ProcWidgetState {
     /// This function *only* updates the displayed process data. If there is a
     /// need to update the actual *stored* data, call it before this
     /// function.
-    pub fn set_table_data(&mut self, data_collection: &DataCollection) {
+    pub fn set_table_data(&mut self, stored_data: &StoredData) {
         let data = match &self.mode {
             ProcWidgetMode::Grouped | ProcWidgetMode::Normal => {
-                self.get_normal_data(&data_collection.process_data.process_harvest)
-            }
-            ProcWidgetMode::Tree { collapsed_pids } => {
-                self.get_tree_data(collapsed_pids, data_collection)
+                self.get_normal_data(&stored_data.process_data.process_harvest)
             }
+            ProcWidgetMode::Tree(collapse) => self.get_tree_data(collapse, stored_data),
         };
         self.table.set_data(data);
+        self.force_update_data = false;
     }
 
     fn get_tree_data(
-        &self, collapsed_pids: &HashSet<Pid>, data_collection: &DataCollection,
+        &self, collapsed: &TreeCollapsed, stored_data: &StoredData,
     ) -> Vec<ProcWidgetData> {
         const BRANCH_END: char = '└';
         const BRANCH_SPLIT: char = '├';
@@ -427,10 +501,10 @@ impl ProcWidgetState {
             process_parent_mapping,
             orphan_pids,
             ..
-        } = &data_collection.process_data;
+        } = &stored_data.process_data;
 
         // Only keep a set of the kept PIDs.
-        let kept_pids = data_collection
+        let kept_pids = stored_data
             .process_data
             .process_harvest
             .iter()
@@ -570,8 +644,9 @@ impl ProcWidgetState {
             let disabled = !kept_pids.contains(&process.pid);
             let is_last = *siblings_left == 0;
 
-            if collapsed_pids.contains(&process.pid) {
+            if collapsed.is_collapsed(process.pid) {
                 let mut summed_process = process.clone();
+                let mut has_children = false;
 
                 if let Some(children_pids) = filtered_tree.get(&process.pid) {
                     let mut sum_queue = children_pids
@@ -594,13 +669,27 @@ impl ProcWidgetState {
                             }));
                         }
                     }
+
+                    has_children = !children_pids.is_empty();
                 }
 
-                let prefix = if prefixes.is_empty() {
-                    "+ ".to_string()
+                // This is so that if an entry is "collapsed" but there are no children, avoid drawing the "+".
+                let prefix = if has_children {
+                    if prefixes.is_empty() {
+                        "+ ".to_string()
+                    } else {
+                        format!(
+                            "{}{}{} + ",
+                            prefixes.join(""),
+                            if is_last { BRANCH_END } else { BRANCH_SPLIT },
+                            BRANCH_HORIZONTAL
+                        )
+                    }
+                } else if prefixes.is_empty() {
+                    String::default()
                 } else {
                     format!(
-                        "{}{}{} + ",
+                        "{}{}{} ",
                         prefixes.join(""),
                         if is_last { BRANCH_END } else { BRANCH_SPLIT },
                         BRANCH_HORIZONTAL
@@ -678,7 +767,8 @@ impl ProcWidgetState {
 
         let mut id_pid_map: HashMap<String, Vec<Pid>> = HashMap::default();
         let mut filtered_data: Vec<ProcWidgetData> = if let ProcWidgetMode::Grouped = self.mode {
-            let mut id_process_mapping: HashMap<&String, ProcessHarvest> = HashMap::default();
+            let mut id_process_mapping: HashMap<&String, ProcWidgetData> = HashMap::default();
+
             for process in filtered_iter {
                 let id = if is_using_command {
                     &process.command
@@ -693,30 +783,46 @@ impl ProcWidgetState {
                     id_pid_map.insert(id.clone(), vec![pid]);
                 }
 
-                if let Some(grouped_process_harvest) = id_process_mapping.get_mut(id) {
-                    grouped_process_harvest.add(process);
+                if let Some(pwd) = id_process_mapping.get_mut(id) {
+                    pwd.cpu_usage_percent += process.cpu_usage_percent;
+
+                    match &mut pwd.mem_usage {
+                        MemUsage::Percent(usage) => {
+                            *usage += process.mem_usage_percent;
+                        }
+                        MemUsage::Bytes(usage) => {
+                            *usage += process.mem_usage;
+                        }
+                    }
+
+                    pwd.rps += process.read_per_sec;
+                    pwd.wps += process.write_per_sec;
+                    pwd.total_read += process.total_read;
+                    pwd.total_write += process.total_write;
+                    pwd.time = pwd.time.max(process.time);
+                    #[cfg(feature = "gpu")]
+                    {
+                        pwd.gpu_usage += process.gpu_util;
+                        match &mut pwd.gpu_mem_usage {
+                            MemUsage::Percent(usage) => {
+                                *usage += process.gpu_mem_percent;
+                            }
+                            MemUsage::Bytes(usage) => {
+                                *usage += process.gpu_mem;
+                            }
+                        }
+                    }
+
+                    pwd.num_similar += 1;
                 } else {
-                    // FIXME: [PERF] could maybe eliminate an allocation here in the grouped mode...
-                    // or maybe just avoid the entire transformation step, making an alloc fine.
-                    id_process_mapping.insert(id, process.clone());
+                    id_process_mapping.insert(
+                        id,
+                        ProcWidgetData::from_data(process, is_using_command, is_mem_percent),
+                    );
                 }
             }
 
-            id_process_mapping
-                .values()
-                .map(|process| {
-                    let id = if is_using_command {
-                        &process.command
-                    } else {
-                        &process.name
-                    };
-
-                    let num_similar = id_pid_map.get(id).map(|val| val.len()).unwrap_or(1) as u64;
-
-                    ProcWidgetData::from_data(process, is_using_command, is_mem_percent)
-                        .num_similar(num_similar)
-                })
-                .collect()
+            id_process_mapping.into_values().collect()
         } else {
             filtered_iter
                 .map(|process| ProcWidgetData::from_data(process, is_using_command, is_mem_percent))
@@ -741,11 +847,11 @@ impl ProcWidgetState {
         if let Some(index) = self.column_mapping.get_index_of(&ProcWidgetColumn::Mem) {
             if let Some(mem) = self.get_mut_proc_col(index) {
                 match mem {
-                    ProcColumn::MemoryVal => {
-                        *mem = ProcColumn::MemoryPercent;
+                    ProcColumn::MemValue => {
+                        *mem = ProcColumn::MemPercent;
                     }
-                    ProcColumn::MemoryPercent => {
-                        *mem = ProcColumn::MemoryVal;
+                    ProcColumn::MemPercent => {
+                        *mem = ProcColumn::MemValue;
                     }
                     _ => unreachable!(),
                 }
@@ -758,11 +864,11 @@ impl ProcWidgetState {
         if let Some(index) = self.column_mapping.get_index_of(&ProcWidgetColumn::GpuMem) {
             if let Some(mem) = self.get_mut_proc_col(index) {
                 match mem {
-                    ProcColumn::GpuMem => {
+                    ProcColumn::GpuMemValue => {
                         *mem = ProcColumn::GpuMemPercent;
                     }
                     ProcColumn::GpuMemPercent => {
-                        *mem = ProcColumn::GpuMem;
+                        *mem = ProcColumn::GpuMemValue;
                     }
                     _ => unreachable!(),
                 }
@@ -819,14 +925,28 @@ impl ProcWidgetState {
         }
     }
 
-    pub fn toggle_current_tree_branch_entry(&mut self) {
-        if let ProcWidgetMode::Tree { collapsed_pids } = &mut self.mode {
+    pub fn collapse_current_tree_branch_entry(&mut self) {
+        if let ProcWidgetMode::Tree(collapsed) = &mut self.mode {
             if let Some(process) = self.table.current_item() {
-                let pid = process.pid;
+                collapsed.collapse(process.pid);
+                self.force_data_update();
+            }
+        }
+    }
 
-                if !collapsed_pids.remove(&pid) {
-                    collapsed_pids.insert(pid);
-                }
+    pub fn expand_current_tree_branch_entry(&mut self) {
+        if let ProcWidgetMode::Tree(collapsed) = &mut self.mode {
+            if let Some(process) = self.table.current_item() {
+                collapsed.expand(process.pid);
+                self.force_data_update();
+            }
+        }
+    }
+
+    pub fn toggle_current_tree_branch_entry(&mut self) {
+        if let ProcWidgetMode::Tree(collapsed) = &mut self.mode {
+            if let Some(process) = self.table.current_item() {
+                collapsed.toggle(process.pid);
                 self.force_data_update();
             }
         }
@@ -982,13 +1102,6 @@ impl ProcWidgetState {
         self.proc_search.search_state.walk_backward();
     }
 
-    /// Returns the number of columns *enabled*. Note this differs from
-    /// *visible* - a column may be enabled but not visible (e.g. off
-    /// screen).
-    pub fn num_enabled_columns(&self) -> usize {
-        self.table.columns.iter().filter(|c| !c.is_hidden).count()
-    }
-
     /// Sets the [`ProcWidgetState`]'s current sort index to whatever was in the
     /// sort table if possible, then closes the sort table.
     pub(crate) fn use_sort_table_value(&mut self) {
@@ -1045,11 +1158,12 @@ mod test {
             id: "A".into(),
             cpu_usage_percent: 0.0,
             mem_usage: MemUsage::Percent(1.1),
+            virtual_mem: 100,
             rps: 0,
             wps: 0,
             total_read: 0,
             total_write: 0,
-            process_state: "N/A".to_string(),
+            process_state: "N/A",
             process_char: '?',
             #[cfg(target_family = "unix")]
             user: "root".to_string(),
@@ -1109,7 +1223,7 @@ mod test {
         );
 
         data.sort_by_key(|p| p.pid);
-        sort_skip_pid_asc(&ProcColumn::MemoryPercent, &mut data, SortOrder::Descending);
+        sort_skip_pid_asc(&ProcColumn::MemPercent, &mut data, SortOrder::Descending);
         assert_eq!(
             [&b, &a, &c, &d].iter().map(|d| (d.pid)).collect::<Vec<_>>(),
             data.iter().map(|d| (d.pid)).collect::<Vec<_>>(),
@@ -1117,7 +1231,7 @@ mod test {
 
         // Note that the PID ordering for ties is still ascending.
         data.sort_by_key(|p| p.pid);
-        sort_skip_pid_asc(&ProcColumn::MemoryPercent, &mut data, SortOrder::Ascending);
+        sort_skip_pid_asc(&ProcColumn::MemPercent, &mut data, SortOrder::Ascending);
         assert_eq!(
             [&c, &d, &a, &b].iter().map(|d| (d.pid)).collect::<Vec<_>>(),
             data.iter().map(|d| (d.pid)).collect::<Vec<_>>(),
@@ -1140,7 +1254,7 @@ mod test {
 
     fn init_state(table_config: ProcTableConfig, columns: &[ProcWidgetColumn]) -> ProcWidgetState {
         let config = AppConfigFields::default();
-        let styling = ColourPalette::default();
+        let styling = Styles::default();
         let columns = Some(columns.iter().cloned().collect());
 
         ProcWidgetState::new(
@@ -1167,7 +1281,7 @@ mod test {
         let columns = vec![
             ProcColumn::Pid,
             ProcColumn::Name,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::State,
         ];
         let state = init_default_state(&init_columns);
@@ -1185,14 +1299,10 @@ mod test {
         let original_columns = vec![
             ProcColumn::Pid,
             ProcColumn::Name,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::State,
         ];
-        let new_columns = vec![
-            ProcColumn::Count,
-            ProcColumn::Name,
-            ProcColumn::MemoryPercent,
-        ];
+        let new_columns = vec![ProcColumn::Count, ProcColumn::Name, ProcColumn::MemPercent];
 
         let mut state = init_default_state(&init_columns);
         assert_eq!(get_columns(&state.table), original_columns);
@@ -1217,16 +1327,12 @@ mod test {
         ];
         let original_columns = vec![
             ProcColumn::Name,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::User,
             ProcColumn::State,
             ProcColumn::Pid,
         ];
-        let new_columns = vec![
-            ProcColumn::Name,
-            ProcColumn::MemoryPercent,
-            ProcColumn::Count,
-        ];
+        let new_columns = vec![ProcColumn::Name, ProcColumn::MemPercent, ProcColumn::Count];
 
         let mut state = init_default_state(&init_columns);
         assert_eq!(get_columns(&state.table), original_columns);
@@ -1251,13 +1357,13 @@ mod test {
         let original_columns = vec![
             ProcColumn::Pid,
             ProcColumn::State,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::Command,
         ];
         let new_columns = vec![
             ProcColumn::Pid,
             ProcColumn::State,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::Name,
         ];
 
@@ -1285,13 +1391,13 @@ mod test {
         ];
         let original_columns = vec![
             ProcColumn::Pid,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::State,
             ProcColumn::Name,
         ];
         let new_columns = vec![
             ProcColumn::Pid,
-            ProcColumn::MemoryVal,
+            ProcColumn::MemValue,
             ProcColumn::State,
             ProcColumn::Name,
         ];
@@ -1316,13 +1422,13 @@ mod test {
         ];
         let original_columns = vec![
             ProcColumn::Pid,
-            ProcColumn::MemoryVal,
+            ProcColumn::MemValue,
             ProcColumn::State,
             ProcColumn::Name,
         ];
         let new_columns = vec![
             ProcColumn::Pid,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::State,
             ProcColumn::Name,
         ];
@@ -1351,7 +1457,7 @@ mod test {
         ];
         let original_columns = vec![
             ProcColumn::Pid,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::State,
             ProcColumn::Command,
         ];
@@ -1381,7 +1487,7 @@ mod test {
         ];
         let original_columns = vec![
             ProcColumn::Pid,
-            ProcColumn::MemoryVal,
+            ProcColumn::MemValue,
             ProcColumn::State,
             ProcColumn::Name,
         ];
@@ -1416,13 +1522,13 @@ mod test {
             ProcWidgetColumn::Mem,
         ];
         let original_columns = vec![
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::Pid,
             ProcColumn::State,
             ProcColumn::Name,
         ];
         let new_columns = vec![
-            ProcColumn::MemoryVal,
+            ProcColumn::MemValue,
             ProcColumn::Pid,
             ProcColumn::State,
             ProcColumn::Name,
@@ -1455,14 +1561,10 @@ mod test {
         let original_columns = vec![
             ProcColumn::Name,
             ProcColumn::Pid,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
             ProcColumn::State,
         ];
-        let new_columns = vec![
-            ProcColumn::Name,
-            ProcColumn::Count,
-            ProcColumn::MemoryPercent,
-        ];
+        let new_columns = vec![ProcColumn::Name, ProcColumn::Count, ProcColumn::MemPercent];
 
         let mut state = init_default_state(&init_columns);
         assert_eq!(get_columns(&state.table), original_columns);
@@ -1494,13 +1596,13 @@ mod test {
             ProcColumn::Command,
             ProcColumn::Pid,
             ProcColumn::State,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
         ];
         let new_columns = vec![
             ProcColumn::Name,
             ProcColumn::Pid,
             ProcColumn::State,
-            ProcColumn::MemoryPercent,
+            ProcColumn::MemPercent,
         ];
 
         let table_config = ProcTableConfig {
@@ -1516,4 +1618,44 @@ mod test {
         state.toggle_command();
         assert_eq!(get_columns(&state.table), original_columns);
     }
+
+    /// Sanity test to ensure tree collapse logic works, both when enabled-by-default or disabled-by-default.
+    #[test]
+    fn test_tree_collapse() {
+        {
+            let mut collapsed_by_default = TreeCollapsed::new(true);
+
+            assert!(collapsed_by_default.is_collapsed(1));
+
+            collapsed_by_default.collapse(1);
+            assert!(collapsed_by_default.is_collapsed(1));
+
+            collapsed_by_default.expand(1);
+            assert!(!collapsed_by_default.is_collapsed(1));
+
+            collapsed_by_default.toggle(1);
+            assert!(collapsed_by_default.is_collapsed(1));
+
+            collapsed_by_default.toggle(1);
+            assert!(!collapsed_by_default.is_collapsed(1));
+        }
+
+        {
+            let mut expanded_by_default = TreeCollapsed::new(false);
+
+            assert!(!expanded_by_default.is_collapsed(1));
+
+            expanded_by_default.collapse(1);
+            assert!(expanded_by_default.is_collapsed(1));
+
+            expanded_by_default.expand(1);
+            assert!(!expanded_by_default.is_collapsed(1));
+
+            expanded_by_default.toggle(1);
+            assert!(expanded_by_default.is_collapsed(1));
+
+            expanded_by_default.toggle(1);
+            assert!(!expanded_by_default.is_collapsed(1));
+        }
+    }
 }
